# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-06-05 09:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0011_auto_20190524_1403'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='member',
            options={},
        ),
        migrations.AddField(
            model_name='project',
            name='driveID',
            field=models.TextField(blank=True),
        ),
    ]
